@@ -16,7 +16,7 @@ class TestGuide(TestCase):
 
         cm = MagicMock()
         cm.getcode.return_value = 200
-        cm.read.return_value = json_feed
+        cm.read.return_value = json_feed.encode()
         cm.info.return_value = {'Expires': 'Sat, 25 Aug 2018 22:39:41 GMT',
                                 'Content-Type': 'text/xml'}
         cm.__enter__.return_value = cm
